package feast.core.job.direct;

import feast.core.job.JobMonitor;
import feast.core.model.JobInfo;
import feast.core.model.JobStatus;
import feast.core.model.Metrics;
import java.util.ArrayList;
import java.util.List;
import lombok.extern.slf4j.Slf4j;

@Slf4j
public class DirectRunnerJobMonitor implements JobMonitor {

  private final DirectJobRegistry jobs;
  private final DirectJobStateMapper jobStateMapper;

  public DirectRunnerJobMonitor(DirectJobRegistry jobs) {
    this.jobs = jobs;
    jobStateMapper = new DirectJobStateMapper();
  }

  @Override
  public JobStatus getJobStatus(JobInfo job) {
    DirectJob directJob = jobs.get(job.getId());
    return jobStateMapper.map(directJob.getPipelineResult().getState());
  }

  @Override
  public List<Metrics> getJobMetrics(JobInfo job) {
    // Direct runner provides no job metrics
    return new ArrayList<>();
  }
}
